==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_ms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Buka Imej</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Penampilan</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Sempadan terserong</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Bayang letak</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Warna</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Latar Belakang:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Bayang:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Sorot:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Imej hilang.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Tunggu Sebentar</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Memuatkan imej...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Menjana teka-teki...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Mencipta kepingan...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Memuatkan teka-teki...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Format data tidak diketahui</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Unsur &apos;%1&apos; tidak diketahui</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Ralat menghurai fail.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Memuatkan kepingan...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Mendapatkan kepingan...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Meletak kepingan...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Berjaya</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Pilih Permainan</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Permainan Semasa</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Permainan Baru</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Sifat Imej</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nama:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Tag:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pilih bahasa aplikasi:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Bahasa Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Sila mulakan semula aplikasi ini supaya perubahan bahasa berkesan.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Tambah Imej</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Buang Imej</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Sifat Imej</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 kepingan</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Menyalin imej...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Buang imej terpilih?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Buang imej terpilih?

Terdapat permainan tersimpan menggunakan imej ini yang mana juga dibuang.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Tidak Bertajuk</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Tidak Bertajuk</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 kepingan %2 %3% selesai</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Padam Permainan</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Padam permainan terpilih?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Tinjauan</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Tambah Tag</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Buang Tag</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Dinyahtag</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Semua Imej</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Tidak bertajuk %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soalan</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Buang tag terpilih?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Maaf</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Tag dengan nama tersebut sudah wujud.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Permainan</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Dapatkan Kepingan</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>P&amp;ilih...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Lihat</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zum &amp;Masuk</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zum &amp;Keluar</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Suai M&amp;uat</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Tunjuk T&amp;injauan</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Sk&amp;rin Penuh</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Tetapan</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>P&amp;enampilan...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Bahasa...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ba&amp;ntuan</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Kawalan</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Perih&amp;al</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Perihal &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kawalan</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ambil Kepingan:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Klik Kiri atau Space</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Lepas Kepingan:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pilih Kepingan:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Seret Kiri</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Putar Kepingan:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Klik Kanan, Control + Klik Kiri, atau R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Seret Teka-teki:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Klik Tengah, Shift + Klik Kiri, atau Anak Panah</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zum Teka-teki:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Roda Tatal atau +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Gerak Kursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Gerak tetikus atau </translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Perihal Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Teka-teki susun suai gambar dengan tetromino untuk kepingannya</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Hakcipta &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Dikeluarkan dibawah lesen &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Pilih versi OpenGL</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versi</translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_ms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Buka Imej</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Penampilan</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Sempadan terserong</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Bayang letak</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Warna</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Latar Belakang:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Bayang:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Sorot:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Imej hilang.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Tunggu Sebentar</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Memuatkan imej...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Menjana teka-teki...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Mencipta kepingan...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Memuatkan teka-teki...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Format data tidak diketahui</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Unsur &apos;%1&apos; tidak diketahui</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Ralat menghurai fail.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Memuatkan kepingan...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Mendapatkan kepingan...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Meletak kepingan...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Berjaya</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Pilih Permainan</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Permainan Semasa</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Permainan Baru</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Sifat Imej</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nama:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Tag:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pilih bahasa aplikasi:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Bahasa Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Sila mulakan semula aplikasi ini supaya perubahan bahasa berkesan.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Tambah Imej</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Buang Imej</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Sifat Imej</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 kepingan</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Menyalin imej...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Tidak Bertajuk</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Tidak Bertajuk</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 kepingan %2 %3% selesai</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Padam Permainan</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Padam permainan terpilih?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Tinjauan</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Tambah Tag</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Buang Tag</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Dinyahtag</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Semua Imej</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Tidak bertajuk %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soalan</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Buang tag terpilih?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Maaf</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Tag dengan nama tersebut sudah wujud.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Permainan</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Dapatkan Kepingan</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>P&amp;ilih...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Lihat</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zum &amp;Masuk</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zum &amp;Keluar</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Suai M&amp;uat</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Tunjuk T&amp;injauan</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Sk&amp;rin Penuh</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Tetapan</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>P&amp;enampilan...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Bahasa...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ba&amp;ntuan</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Kawalan</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Perih&amp;al</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Perihal &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kawalan</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ambil Kepingan:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Klik Kiri atau Space</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Lepas Kepingan:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pilih Kepingan:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Seret Kiri</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Putar Kepingan:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Klik Kanan, Control + Klik Kiri, atau R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Seret Teka-teki:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Klik Tengah, Shift + Klik Kiri, atau Anak Panah</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zum Teka-teki:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Roda Tatal atau +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Gerak Kursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Gerak tetikus atau </translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Perihal Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Teka-teki susun suai gambar dengan tetromino untuk kepingannya</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Hakcipta &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Dikeluarkan dibawah lesen &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
